# -*- coding: utf-8 -*-
# Generated by Django 1.9.10 on 2016-10-25 04:58
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Email',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('when', models.DateTimeField(auto_now_add=True, verbose_name='when')),
                ('whom', models.CharField(max_length=254, verbose_name='whom')),
                ('subject', models.CharField(max_length=254, verbose_name='subject')),
                ('body', models.TextField(verbose_name='body')),
                ('status', models.CharField(max_length=254, verbose_name='status')),
            ],
            options={
                'verbose_name': 'email',
                'verbose_name_plural': 'emails',
            },
        ),
    ]



# coding=utf-8

from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from email_helper.models import Email


class EmailAdmin(admin.ModelAdmin):
    list_display = ['when', 'whom', 'subject', 'status']
    search_fields = ['whom', 'subject']
    readonly_fields = ['when', '_body']
    fieldsets = [
        [None, {'fields': ['when', 'whom', 'subject', 'status']}],
        [None, {'fields': ['_body']}],
    ]

    def _body(self, obj):
        return obj.body
    _body.short_description = _(u'body')
    _body.allow_tags = True


admin.site.register(Email, EmailAdmin)



# coding=utf-8

from django.db import models
from django.utils.translation import ugettext, ugettext_lazy as _


class Email(models.Model):
    when = models.DateTimeField(verbose_name=_(u'when'), auto_now_add=True)
    whom = models.CharField(verbose_name=_(u'whom'), max_length=254)
    subject = models.CharField(verbose_name=_(u'subject'), max_length=254)
    body = models.TextField(verbose_name=_(u'body'))
    status = models.CharField(verbose_name=_(u'status'), max_length=254)

    class Meta:
        verbose_name = _(u'email')
        verbose_name_plural = _(u'emails')

    def __unicode__(self):
        return ugettext(u'Email #{0}').format(self.id)



# coding=utf-8

from os.path import basename
from smtplib import SMTPException
from html2text import html2text

from django.template import loader, Context
from django.core.mail import EmailMultiAlternatives


def send_email(addr_from, addr_to, subject, template, context, attachments=None, reply_to=None):
    from email_helper.models import Email

    # Allow for a single address to be passed in.
    if not hasattr(addr_to, '__iter__'):
        addr_to = [addr_to]

    body_html = loader.get_template(template).render(Context(context))
    alternatives_parts = [(body_html, 'text/html')]

    body_txt = html2text(body_html)

    # Load attachments and create name/data tuples.
    attachments_parts = []
    for attachment in attachments or []:
        # Attachments can be pairs of name/data, or filesystem paths.
        if not hasattr(attachment, '__iter__'):
            with open(attachment, 'rb') as f:
                attachments_parts.append((basename(attachment), f.read()))
        else:
            attachments_parts.append(attachment)

    headers = reply_to and {'Reply-To': reply_to}

    msg = EmailMultiAlternatives(subject=subject, body=body_txt, from_email=addr_from, to=addr_to, alternatives=alternatives_parts, attachments=attachments_parts, headers=headers)

    try:
        msg.send()
    except SMTPException as ex:
        status = unicode(ex)
    else:
        status = u'OK'

    Email.objects.create(whom=u', '.join(addr_to), subject=subject, body=body_html, status=status)



# coding=utf-8

import os
from setuptools import setup


README = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()

os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-fs-email-helper',
    version='0.3',
    packages=['email_helper'],
    include_package_data=True,
    install_requires=['html2text'],
    author='Yuri Lya',
    author_email='yuri.lya@fogstream.ru',
    url='https://bitbucket.org/fogstream/django-fs-email-helper',
    license='The MIT License (MIT)',
    description='The Django-related reusable app provides the ability to send multipart emails and store them in a database.',
    long_description=README,
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Framework :: Django",
    ]
)
